==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/product/manufacturers.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	manufacturers.lang.inc.php 2017-11-14 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	'ERROR_DIRECTORY_DOES_NOT_EXIST'   => 'Fehler: Das Verzeichnis %s existiert nicht!',
	'ERROR_DIRECTORY_NOT_WRITEABLE'    => 'Fehler: Das Verzeichnis %s ist schreibgeschützt. Bitte korrigieren Sie die Zugriffsrechte zu diesem Verzeichnis!',
	'ERROR_MISSING_NAME'               => 'Es muss ein Herstellername angegeben werden!',
	'HEADING_SUB_TITLE'                => 'Artikelkatalog',
	'HEADING_TITLE'                    => 'Hersteller',
	'TABLE_HEADING_ACTION'             => 'Aktion',
	'TABLE_HEADING_MANUFACTURERS'      => 'Hersteller',
	'TEXT_DATE_ADDED'                  => 'Hinzugefügt am:',
	'TEXT_DELETE_IMAGE'                => 'Herstellerbild löschen?',
	'TEXT_DELETE_INTRO'                => 'Sind Sie sicher, dass Sie diesen Hersteller löschen möchten?',
	'TEXT_DELETE_PRODUCTS'             => 'Alle Artikel von diesem Hersteller löschen? (inkl. Rezensionen, Angebote und Neuerscheinungen)',
	'TEXT_DELETE_WARNING_PRODUCTS'     => '<b>WARNUNG:</b> Es existieren noch %s Artikel, welche mit diesem Hersteller verbunden sind!',
	'TEXT_EDIT_INTRO'                  => 'Bitte führen Sie alle notwendigen Änderungen durch.',
	'TEXT_EDIT_SUCCESS'                => 'Der Hersteller wurde erfolgreich aktualisiert.',
	'TEXT_HEADING_DELETE_MANUFACTURER' => 'Hersteller löschen',
	'TEXT_HEADING_EDIT_MANUFACTURER'   => 'Hersteller bearbeiten',
	'TEXT_HEADING_NEW_MANUFACTURER'    => 'Neuer Hersteller',
	'TEXT_IMAGE_NONEXISTENT'           => 'BILD NICHT VORHANDEN',
	'TEXT_INFO_DELETE_SUCCESS'         => 'Der Hersteller wurde erfolgreich gelöscht.',
	'TEXT_LAST_MODIFIED'               => 'Bearbeitet am:',
	'TEXT_MANUFACTURERS'               => 'Hersteller: ',
	'TEXT_MANUFACTURERS_IMAGE'         => 'Herstellerbild: ',
	'TEXT_MANUFACTURERS_NAME'          => 'Herstellername: ',
	'TEXT_MANUFACTURERS_URL'           => 'Hersteller URL: ',
	'TEXT_MARKED_ELEMENTS'             => 'Markiertes Element',
	'TEXT_NEW_INTRO'                   => 'Bitte geben Sie den neuen Hersteller mit allen relevanten Daten ein.',
	'TEXT_PRODUCTS'                    => 'Artikel:',
	'TEXT_RENAMED_IMAGE'               => 'Das Herstellerbild wurde umbennant, da ein Herstellerbild mit diesem Namen bereits existiert.',
	'TEXT_SAVE_SUCCESS'                => 'Der Hersteller wurde erfolgreich gespeichert.'
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/product/manufacturers.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	manufacturers.lang.inc.php 2017-11-14 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	'ERROR_DIRECTORY_DOES_NOT_EXIST'   => 'Fehler: Das Verzeichnis %s existiert nicht!',
	'ERROR_DIRECTORY_NOT_WRITEABLE'    => 'Fehler: Das Verzeichnis %s ist schreibgeschützt. Bitte korrigiere die Zugriffsrechte zu diesem Verzeichnis!',
	'ERROR_MISSING_NAME'               => 'Es muss ein Herstellername angegeben werden!',
	'HEADING_SUB_TITLE'                => 'Artikelkatalog',
	'HEADING_TITLE'                    => 'Hersteller',
	'TABLE_HEADING_ACTION'             => 'Aktion',
	'TABLE_HEADING_MANUFACTURERS'      => 'Hersteller',
	'TEXT_DATE_ADDED'                  => 'Hinzugefügt am:',
	'TEXT_DELETE_IMAGE'                => 'Herstellerbild löschen?',
	'TEXT_DELETE_INTRO'                => 'Bist du sicher, dass du diesen Hersteller löschen möchtest?',
	'TEXT_DELETE_PRODUCTS'             => 'Alle Artikel von diesem Hersteller löschen? (inkl. Rezensionen, Angebote und Neuerscheinungen)',
	'TEXT_DELETE_WARNING_PRODUCTS'     => '<b>WARNUNG:</b> Es existieren noch %s Artikel, welche mit diesem Hersteller verbunden sind!',
	'TEXT_EDIT_INTRO'                  => 'Bitte führe alle notwendigen Änderungen durch.',
	'TEXT_EDIT_SUCCESS'                => 'Der Hersteller wurde erfolgreich aktualisiert.',
	'TEXT_HEADING_DELETE_MANUFACTURER' => 'Hersteller löschen',
	'TEXT_HEADING_EDIT_MANUFACTURER'   => 'Hersteller bearbeiten',
	'TEXT_HEADING_NEW_MANUFACTURER'    => 'Neuer Hersteller',
	'TEXT_IMAGE_NONEXISTENT'           => 'BILD NICHT VORHANDEN',
	'TEXT_INFO_DELETE_SUCCESS'         => 'Der Hersteller wurde erfolgreich gelöscht.',
	'TEXT_LAST_MODIFIED'               => 'Bearbeitet am:',
	'TEXT_MANUFACTURERS'               => 'Hersteller: ',
	'TEXT_MANUFACTURERS_IMAGE'         => 'Herstellerbild: ',
	'TEXT_MANUFACTURERS_NAME'          => 'Herstellername: ',
	'TEXT_MANUFACTURERS_URL'           => 'Hersteller URL: ',
	'TEXT_MARKED_ELEMENTS'             => 'Markiertes Element',
	'TEXT_NEW_INTRO'                   => 'Bitte gib den neuen Hersteller mit allen relevanten Daten ein.',
	'TEXT_PRODUCTS'                    => 'Artikel:',
	'TEXT_RENAMED_IMAGE'               => 'Das Herstellerbild wurde umbennant, da ein Herstellerbild mit diesem Namen bereits existiert.',
	'TEXT_SAVE_SUCCESS'                => 'Der Hersteller wurde erfolgreich gespeichert.'
];
